@@ -3,7 +3,7 @@ BEGIN {
   $HTML::EasyForm::Field::Checkbox::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $HTML::EasyForm::Field::Checkbox::VERSION = '0.100';
+  $HTML::EasyForm::Field::Checkbox::VERSION = '0.101';
 }
 # ABSTRACT: Checkbox
 
@@ -20,6 +20,19 @@ has checkbox_value => (
 	default => sub { 'checkbox_is_checked_and_selected' },
 );
 
+sub input_to_value {
+	my ( $self ) = @_;
+	$self->value($self->input_value eq $self->checkbox_value ? 1 : 0);
+}
+
+sub value_to_output {
+	my ( $self ) = @_;
+	$self->output_value($self->value);
+}
+
+sub notempty { 0 }
+sub required { 0 }
+
 1;
 __END__
 =pod
@@ -30,7 +43,7 @@ HTML::EasyForm::Field::Checkbox - Checkbox
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 AUTHOR
 
